@@ -10,12 +10,15 @@ make.panel.svysmooth<-function(design,bandwidth=NULL){
 
 
 svyplot<-function(formula, design,...) UseMethod("svyplot",design)
+
+if(getRversion() >= "2.15.1")  utils::globalVariables("hcell")
+
 svyplot.default<-function(formula,
                   design,
                   style=c("bubble","hex","grayhex","subsample","transparent"),
                   sample.size=500, subset=NULL,legend=1,inches=0.05,
                   amount=NULL,basecol="black",alpha=c(0,0.8), xbins=30,...){
-  
+
   style<-match.arg(style)
   if (style %in% c("hex","grayhex") && !require(hexbin)){
     stop(style," plots require the hexbin package")
@@ -28,17 +31,17 @@ svyplot.default<-function(formula,
 
   W<-weights(design, "sampling")
 
-  mf<-model.frame(formula, design$variables,na.action=na.pass)  
+  mf<-model.frame(formula, design$variables,na.action=na.pass)
   Y<-model.response(mf)
   X<-mf[,attr(attr(mf,"terms"),"term.labels")]
-  
-  switch(style, 
+
+  switch(style,
          bubble={
            if(is.function(basecol)) basecol<-basecol(model.frame(design))
            symbols(X,Y,circles=sqrt(W),inches=inches,fg=basecol,...)
          },
          hex={
-           if (exists("hcell")) {
+           if (exists("hcell", mode = "function")) {
              ## old version of hexbin
              rval<-hexbin(X,Y,xbins=xbins)
              cell<-hcell(X,Y)$cell
@@ -59,10 +62,10 @@ svyplot.default<-function(formula,
                               function(ii) weighted.mean(Y[ii],W[ii])))
              gplot.hexbin(rval, legend=legend, style="centroids",...)
            }
-           
+
          },
          grayhex={
-           if (exists("hcell")) {
+           if (exists("hcell", mode = "function")) {
              ## old version of hexbin
              rval<-hexbin(X,Y,xbins=xbins)
              cell<-hcell(X,Y)$cell
@@ -106,14 +109,14 @@ svyplot.default<-function(formula,
 
 svyboxplot<-function(formula, design,all.outliers=FALSE,...) UseMethod("svyboxplot",design)
 svyboxplot.default<-function(formula, design,  all.outliers=FALSE,col=NULL,names,...){
-    
+
     formula<-as.formula(formula)
     if(length(formula)!=3) stop("need a two-sided formula")
     ##if(length(formula[[3]])>2) stop("only one rhs variable allowed")
-    
+
     outcome<-eval(bquote(~.(formula[[2]])))
     outcome.values<-model.frame(outcome, model.frame(design),na.action=na.pass)
-    
+
     if (length(attr(terms(formula),"term.labels"))){
         groups<-eval(bquote(~.(formula[[3]])))
         qs <- svyby(outcome,groups,design,svyquantile,ci=FALSE,
@@ -168,7 +171,7 @@ svycoplot.default<-function(formula, design, style=c("hexbin","transparent"),
   require(lattice)
   style<-match.arg(style)
   wt<-weights(design,"sampling")
-  
+
   switch(style,
          hexbin={
            require(hexbin) || stop("hexbin package is required (from Bioconductor)")
@@ -176,9 +179,9 @@ svycoplot.default<-function(formula, design, style=c("hexbin","transparent"),
            xyplot(formula, data=model.frame(design), xbins=xbins,
                   panel=function(x,y,style="centroids",xbins,subscripts,...) {
                     if (!length(x)) return(panel.xyplot(x,y,...))
-                    vp<-current.viewport()
-                    wd<-convertWidth(vp$width,unitTo="cm",valueOnly=TRUE)
-                    ht<-convertHeight(vp$height,unitTo="cm",valueOnly=TRUE)
+                    vp<-grid::current.viewport()
+                    wd<-grid::convertWidth(vp$width,unitTo="cm",valueOnly=TRUE)
+                    ht<-grid::convertHeight(vp$height,unitTo="cm",valueOnly=TRUE)
                     W<-wt[subscripts]
                     rval<-hexbin(x,y,IDs=TRUE,xbins=xbins,shape=ht/wd,xbnds=vp$xscale,ybnds=vp$yscale)
                     cell<-rval@cID
@@ -200,7 +203,7 @@ svycoplot.default<-function(formula, design, style=c("hexbin","transparent"),
            minw<-0
            alphas<- (alpha[1]*(maxw-wt)+alpha[2]*(wt-minw))/(maxw-minw)
            cols<-transcol(basecol,alphas)
-           xyplot(formula, data=model.frame(design), 
+           xyplot(formula, data=model.frame(design),
                   panel=function(x,y,basecol="black",subscripts,...) {
                     a<-alphas[subscripts]
                     panel.xyplot(x,y,col=cols[subscripts],pch=19,...)
@@ -216,7 +219,7 @@ barplot.svrepstat<-function(height,...) barplot(coef(height),...)
 plot.svystat<-function(x,...) barplot(coef(x),...)
 plot.svrepstat<-function(x,...) barplot(coef(x),...)
 
-barplot.svyby<-function(height,beside=TRUE,...){    
+barplot.svyby<-function(height,beside=TRUE,...){
   aa <- attr(height, "svyby")
   rval <- height[, max(aa$margins) + (1:aa$nstats)]
   if (is.null(dim(rval))) {
